@@ -1,7 +1,7 @@
 --[[
 More Blocks: crafting recipes
 
-Copyright © 2011-2019 Hugo Locurcio and contributors.
+Copyright © 2011-2020 Hugo Locurcio and contributors.
 Licensed under the zlib license. See LICENSE.md for more information.
 --]]
 
@@ -348,12 +348,36 @@ minetest.register_craft({
 	recipe = {"moreblocks:sweeper", "default:glass"},
 })
 
+minetest.register_craft({
+	output = "moreblocks:trap_clean_glass",
+	type = "shapeless",
+	recipe = {"default:mese_crystal_fragment", "moreblocks:clean_glass"},
+})
+
+minetest.register_craft({
+	output = "moreblocks:trap_clean_glass",
+	type = "shapeless",
+	recipe = {"moreblocks:sweeper", "moreblocks:trap_glass"},
+})
+
 minetest.register_craft({
 	output = "moreblocks:glow_glass",
 	type = "shapeless",
 	recipe = {"default:torch", "default:glass"},
 })
 
+minetest.register_craft({
+	output = "moreblocks:clean_glow_glass",
+	type = "shapeless",
+	recipe = {"default:torch", "moreblocks:clean_glass"},
+})
+
+minetest.register_craft({
+	output = "moreblocks:clean_glow_glass",
+	type = "shapeless",
+	recipe = {"moreblocks:sweeper", "moreblocks:glow_glass"},
+})
+
 minetest.register_craft({
 	output = "moreblocks:trap_glow_glass",
 	type = "shapeless",
@@ -366,6 +390,26 @@ minetest.register_craft({
 	recipe = {"default:mese_crystal_fragment", "moreblocks:glow_glass"},
 })
 
+-- several recipes are possible for the trap+clean+glow, we only present 3 of them
+minetest.register_craft({
+	output = "moreblocks:trap_clean_glow_glass",
+	type = "shapeless",
+	recipe = {"default:mese_crystal_fragment", "moreblocks:clean_glow_glass"},
+})
+
+minetest.register_craft({
+	output = "moreblocks:trap_clean_glow_glass",
+	type = "shapeless",
+	recipe = {"default:mese_crystal_fragment", "moreblocks:clean_glass", "default:torch"},
+})
+
+minetest.register_craft({
+	output = "moreblocks:trap_clean_glow_glass",
+	type = "shapeless",
+	recipe = {"moreblocks:sweeper", "moreblocks:trap_glow_glass" },
+})
+
+
 minetest.register_craft({
 	output = "moreblocks:super_glow_glass",
 	type = "shapeless",
@@ -378,6 +422,24 @@ minetest.register_craft({
 	recipe = {"default:torch", "moreblocks:glow_glass"},
 })
 
+minetest.register_craft({
+	output = "moreblocks:clean_super_glow_glass",
+	type = "shapeless",
+	recipe = {"default:torch", "default:torch", "moreblocks:clean_glass"},
+})
+
+minetest.register_craft({
+	output = "moreblocks:clean_super_glow_glass",
+	type = "shapeless",
+	recipe = {"default:torch", "moreblocks:clean_glow_glass"},
+})
+
+minetest.register_craft({
+	output = "moreblocks:clean_super_glow_glass",
+	type = "shapeless",
+	recipe = {"moreblocks:sweeper", "moreblocks:super_glow_glass"},
+})
+
 
 minetest.register_craft({
 	output = "moreblocks:trap_super_glow_glass",
@@ -391,6 +453,32 @@ minetest.register_craft({
 	recipe = {"default:mese_crystal_fragment", "moreblocks:super_glow_glass"},
 })
 
+-- several recipes are possible for the trap+clean+glow, we only present 4 of them
+minetest.register_craft({
+	output = "moreblocks:trap_clean_super_glow_glass",
+	type = "shapeless",
+	recipe = {"default:mese_crystal_fragment", "moreblocks:clean_super_glow_glass"},
+})
+
+minetest.register_craft({
+	output = "moreblocks:trap_clean_super_glow_glass",
+	type = "shapeless",
+	recipe = {"default:mese_crystal_fragment", "moreblocks:clean_glow_glass", "default:torch"},
+})
+
+minetest.register_craft({
+	output = "moreblocks:trap_clean_super_glow_glass",
+	type = "shapeless",
+	recipe = {"default:mese_crystal_fragment", "moreblocks:clean_glass", "default:torch", "default:torch"},
+})
+
+minetest.register_craft({
+	output = "moreblocks:trap_clean_super_glow_glass",
+	type = "shapeless",
+	recipe = {"moreblocks:sweeper", "moreblocks:trap_super_glow_glass" },
+})
+
+
 minetest.register_craft({
 	output = "moreblocks:coal_stone",
 	type = "shapeless",
@@ -512,6 +600,22 @@ minetest.register_craft({
 	}
 })
 
+minetest.register_craft({
+	output = "moreblocks:desert_cobble_compressed",
+	recipe = {
+		{"default:desert_cobble", "default:desert_cobble", "default:desert_cobble"},
+		{"default:desert_cobble", "default:desert_cobble", "default:desert_cobble"},
+		{"default:desert_cobble", "default:desert_cobble", "default:desert_cobble"},
+	}
+})
+
+minetest.register_craft({
+	output = "default:desert_cobble 9",
+	recipe = {
+		{"moreblocks:desert_cobble_compressed"},
+	}
+})
+
 minetest.register_craft({
 	type = "cooking", output = "moreblocks:tar", recipe = "default:pine_tree",
 })
