@@ -1,30 +1,53 @@
 --[[
 More Blocks: redefinitions of default stuff
 
-Copyright (c) 2011-2017 Hugo Locurcio and contributors.
+Copyright © 2011-2020 Hugo Locurcio and contributors.
 Licensed under the zlib license. See LICENSE.md for more information.
 --]]
 
 -- Redefinitions of some default crafting recipes:
 
-minetest.register_craft({
-	output = "default:sign_wall 4",
+-- Signs: +1
+minetest.clear_craft({
 	recipe = {
-		{"default:wood", "default:wood", "default:wood"},
-		{"default:wood", "default:wood", "default:wood"},
-		{"", "default:stick", ""},
+		{'default:steel_ingot', 'default:steel_ingot', 'default:steel_ingot'},
+		{'default:steel_ingot', 'default:steel_ingot', 'default:steel_ingot'},
+		{'', 'group:stick', ''},
+	}
+})
+
+minetest.clear_craft({
+	recipe = {
+		{'group:wood', 'group:wood', 'group:wood'},
+		{'group:wood', 'group:wood', 'group:wood'},
+		{'', 'group:stick', ''},
 	}
 })
 
 minetest.register_craft({
-	output = "default:ladder 4",
+	output = 'default:sign_wall_steel 4',
 	recipe = {
-		{"default:stick", "", "default:stick"},
-		{"default:stick", "default:stick", "default:stick"},
-		{"default:stick", "", "default:stick"},
+		{'default:steel_ingot', 'default:steel_ingot', 'default:steel_ingot'},
+		{'default:steel_ingot', 'default:steel_ingot', 'default:steel_ingot'},
+		{'', 'group:stick', ''},
 	}
 })
 
+minetest.register_craft({
+	output = 'default:sign_wall_wood 4',
+	recipe = {
+		{'group:wood', 'group:wood', 'group:wood'},
+		{'group:wood', 'group:wood', 'group:wood'},
+		{'', 'group:stick', ''},
+	}
+})
+
+
+minetest.clear_craft({
+	recipe = {
+		{"default:papyrus", "default:papyrus", "default:papyrus"}
+	}
+})
 minetest.register_craft({
 	output = "default:paper 4",
 	recipe = {
@@ -32,6 +55,7 @@ minetest.register_craft({
 	}
 })
 
+
 minetest.register_craft({
 	output = "default:rail 24",
 	recipe = {
